@@ -21,7 +21,8 @@ import unittest
 from transformers.models.bert.tokenization_bert import WordpieceTokenizer
 
 from sudachitra import BertSudachipyTokenizer, SudachipyWordTokenizer
-from sudachitra.tokenization_bert_sudachipy import VOCAB_FILES_NAMES, WORD_FORM_TYPES
+from sudachitra.tokenization_bert_sudachipy import VOCAB_FILES_NAMES
+from sudachitra.word_formatter import word_formatter
 
 
 class BertSudachipyTokenizationTest(unittest.TestCase):
@@ -90,7 +91,7 @@ class BertSudachipyTokenizationTest(unittest.TestCase):
             return
 
         self.assertListEqual(
-            list(map(WORD_FORM_TYPES['surface'],
+            list(map(word_formatter('surface', tokenizer.sudachi_dict),
                      tokenizer.tokenize("appleはsmall辞書に、apple pieはcore辞書に、apple storeはfull辞書に収録されている。"))),
             ["apple", "は", "small", "辞書", "に", "、", "apple", " ", "pie", "は", "core", "辞書", "に", "、",
              "apple", " ", "store", "は", "full", "辞書", "に", "収録", "さ", "れ", "て", "いる", "。"]
@@ -103,7 +104,7 @@ class BertSudachipyTokenizationTest(unittest.TestCase):
             return
 
         self.assertListEqual(
-            list(map(WORD_FORM_TYPES['surface'],
+            list(map(word_formatter('surface', tokenizer.sudachi_dict),
                      tokenizer.tokenize("appleはsmall辞書に、apple pieはcore辞書に、apple storeはfull辞書に収録されている。"))),
             ["apple", "は", "small", "辞書", "に", "、", "apple pie", "は", "core", "辞書", "に", "、",
              "apple", " ", "store", "は", "full", "辞書", "に", "収録", "さ", "れ", "て", "いる", "。"]
@@ -116,7 +117,7 @@ class BertSudachipyTokenizationTest(unittest.TestCase):
             return
 
         self.assertListEqual(
-            list(map(WORD_FORM_TYPES['surface'],
+            list(map(word_formatter('surface', tokenizer.sudachi_dict),
                      tokenizer.tokenize("appleはsmall辞書に、apple pieはcore辞書に、apple storeはfull辞書に収録されている。"))),
             ["apple", "は", "small", "辞書", "に", "、", "apple pie", "は", "core", "辞書", "に", "、",
              "apple store", "は", "full", "辞書", "に", "収録", "さ", "れ", "て", "いる", "。"]
@@ -196,6 +197,29 @@ class BertSudachipyTokenizationTest(unittest.TestCase):
             ["Apple", "や", "Apple", "の", "辞書", "形", "は", "Apple", "で", "正規", "形", "は", "アップル", "で", "ある", "。"]
         )
 
+    def test_sudachipy_tokenizer_normalized_form_leaved_conjugation(self):
+        tokenizer = self.tokenizer_class(self.vocab_file, do_subword_tokenize=False,
+                                         word_form_type='normalized_conjugation')
+
+        self.assertListEqual(
+            tokenizer.tokenize("appleの辞書形はAppleで正規形はアップルである。"),
+            ["アップル", "の", "辞書", "形", "は", "アップル", "で", "正規", "形", "は", "アップル", "で", "有る", "。"]
+        )
+
+    def test_sudachipy_tokenizer_normalized_form_leaved_conjugation_can_do(self):
+        tokenizer = self.tokenizer_class(self.vocab_file, do_subword_tokenize=False,
+                                         word_form_type='normalized_conjugation', sudachipy_kwargs={"split_mode": "C"})
+
+        self.assertListEqual(
+            tokenizer.tokenize("畳み込めたので大丈夫です。"),
+            ["畳み込み", "た", "の", "で", "大丈夫", "です", "。"]
+        )
+
+        self.assertListEqual(
+            tokenizer.tokenize("泳げます。"),
+            ["泳ぎ", "ます", "。"]
+        )
+
     def test_sudachipy_tokenizer_unit_a(self):
         try:
             tokenizer = SudachipyWordTokenizer(split_mode="A")
@@ -203,7 +227,7 @@ class BertSudachipyTokenizationTest(unittest.TestCase):
             return
 
         self.assertListEqual(
-            list(map(WORD_FORM_TYPES['surface'], tokenizer.tokenize("徳島阿波おどり空港"))),
+            list(map(word_formatter('surface', tokenizer.sudachi_dict), tokenizer.tokenize("徳島阿波おどり空港"))),
             ["徳島", "阿波", "おどり", "空港"]
         )
 
@@ -214,7 +238,7 @@ class BertSudachipyTokenizationTest(unittest.TestCase):
             return
 
         self.assertListEqual(
-            list(map(WORD_FORM_TYPES['surface'], tokenizer.tokenize("徳島阿波おどり空港"))),
+            list(map(word_formatter('surface', tokenizer.sudachi_dict), tokenizer.tokenize("徳島阿波おどり空港"))),
             ["徳島", "阿波おどり", "空港"]
         )
 
@@ -225,7 +249,7 @@ class BertSudachipyTokenizationTest(unittest.TestCase):
             return
 
         self.assertListEqual(
-            list(map(WORD_FORM_TYPES['surface'], tokenizer.tokenize("徳島阿波おどり空港"))),
+            list(map(word_formatter('surface', tokenizer.sudachi_dict), tokenizer.tokenize("徳島阿波おどり空港"))),
             ["徳島阿波おどり空港"]
         )
 
